@@ -4,7 +4,7 @@ use strict;
 use Mojo::Base 'Mojolicious::Plugin';
 use MongoDB;
 
-our $VERSION = '0.05';
+our $VERSION = '1.05';
 
 sub register {
     my $self = shift;
@@ -39,7 +39,7 @@ Mojolicious::Plugin::Mongodb - Use MongoDB in Mojolicious
 
 =head1 VERSION
 
-Version 0.05
+Version 1.05
 
 =head1 SYNOPSIS
 
@@ -106,9 +106,7 @@ Ben van Staveren, C<< <madcat at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-mojolicious-plugin-mongodb at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Mojolicious-Plugin-Mongodb>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs through the web interface at L<http://bitbucket.org/xirinet/mojolicious-plugin-mongodb/issues>  
 
 =head1 CONTRIBUTING
 
@@ -127,10 +125,6 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Mojolicious-Plugin-Mongodb>
-
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/Mojolicious-Plugin-Mongodb>
